@@ -1,5 +1,5 @@
 """
-Open Generation and Transmission Operation and Expansion Planning Model with RES and ESS (openTEPES) - September 30, 2021
+Open Generation and Transmission Operation and Expansion Planning Model with RES and ESS (openTEPES) - October 31, 2021
 """
 
 import time
@@ -37,12 +37,12 @@ def ProblemSolving(DirName, CaseName, SolverName, OptModel, mTEPES):
         # Solver.options['BarQCPConvTol' ] = 0.025
         Solver.options['MIPGap'        ] = 0.01
         Solver.options['Threads'       ] = int((psutil.cpu_count(logical=True) + psutil.cpu_count(logical=False))/2)
-        Solver.options['TimeLimit'     ] =    7200
-        Solver.options['IterationLimit'] = 7200000
+        Solver.options['TimeLimit'     ] =    14400
+        Solver.options['IterationLimit'] = 14400000
     if mTEPES.pIndBinGenInvest()*len(mTEPES.gc) + mTEPES.pIndBinNetInvest()*len(mTEPES.lc) + mTEPES.pIndBinGenOperat()*len(mTEPES.nr) + mTEPES.pIndBinLineCommit()*len(mTEPES.la) + len(mTEPES.g2g) == 0:
-        if SolverName == 'gurobi':
-            Solver.options['relax_integrality'] = 1
-            Solver.options['Crossover'    ] = -1
+        if SolverName == 'gurobi' or SolverName == 'mosek':
+            Solver.options['relax_integrality'] =  1  # introduced to show results of the dual variables
+            Solver.options['Crossover'        ] = -1
         OptModel.dual = Suffix(direction=Suffix.IMPORT)
         OptModel.rc   = Suffix(direction=Suffix.IMPORT)
     SolverResults = Solver.solve(OptModel, tee=True, report_timing=True)               # tee=True displays the log of the solver
@@ -73,9 +73,9 @@ def ProblemSolving(DirName, CaseName, SolverName, OptModel, mTEPES):
             for nr in mTEPES.nr:
                 if sum(1 for g in mTEPES.nr if (nr,g) in mTEPES.g2g or (g,nr) in mTEPES.g2g):
                     OptModel.vMaxCommitment[nr].fix(round(OptModel.vMaxCommitment[nr]()))
-        Solver.options['relax_integrality'] =  1                                               # introduced to show results of the dual variables
-        if SolverName == 'gurobi':
-            Solver.options['Crossover'    ] = -1
+        if SolverName == 'gurobi' or SolverName == 'mosek':
+            Solver.options['relax_integrality'] =  1  # introduced to show results of the dual variables
+            Solver.options['Crossover'        ] = -1
         OptModel.dual = Suffix(direction=Suffix.IMPORT)
         OptModel.rc   = Suffix(direction=Suffix.IMPORT)
         SolverResults = Solver.solve(OptModel, tee=True, report_timing=True, warmstart=True)   # tee=True displays the log of the solver
